@@ -45,17 +45,6 @@ def generate_lookback_contravariant(lookback_windows, contravariants):
             })
     return parameters
 
-def generate_slope_induced(lookback_windows, contravariants, slope_columns):
-    parameters = []
-    for lookback_window in lookback_windows:
-        for contravariant in contravariants:
-            for slope_column in slope_columns:
-                parameters.append({
-                    'lookback_window':lookback_window,
-                    'contravariant':contravariant,
-                    'slope_column' : slope_column
-                })
-    return parameters
 
 def generate_alpha_8(lookback_windows, contravariants, lags):
     parameters = []
@@ -91,6 +80,24 @@ def generate_volume_weighted_high_low_vol(lookback_windows, vol_thresholds, up_t
     return parameters
 
 
+def generate_slope_induced(lookback_windows, contravariants, lags, slope_columns, display):
+    parameters = []
+    for slope_column in slope_columns:
+        for lookback_window in lookback_windows:
+            for contravariant in contravariants:
+                for lag in lags:
+
+                    if lag <= int(lookback_window/2):
+                        parameters.append({
+                            'lookback_window':lookback_window,
+                            'contravariant':contravariant,
+                            'lag':lag,
+                            'slope_column': slope_column,
+                            'display' : display
+                        })
+    return parameters
+
+
 def generate_volume_weighted_high_low_vol_cont(lookback_windows, contravariants, lags, display):
     parameters = []
     for lookback_window in lookback_windows:
